# Astrovishal's python package


## To install

```bash
pip install astrovishalPerceptronPkg-astrovishalthakur==0.0.2
```

## How to use this package

```python
from astrovishal.Perceptron import Perceptron
model = Perceptron(eta=0.3, epochs=10)
```


## References -

*[official python docs for PYPI](https://packaging.python.org/en/latest/tutorials/packaging-projects/)